package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.model.AmsContractBreach;
import com.steerinfo.dil.model.AmsContractTransportPrice;
import com.steerinfo.dil.service.impl.AmsContractBreachServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiModelProperty;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/9/4 11:53
 * @Version:V2.0
 */
@RestController
@RequestMapping("/${api.version}/amscontractbreach")
public class AmsContractBreachController extends BaseRESTfulController {
    @Autowired
    AmsContractBreachServiceImpl amsContractBreachService;
    @Autowired
    ColumnDataUtil columnDataUtil;
    @Autowired
    ESFeign esFeign;

    /**
     * 展示违约规则
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示展示违约规则列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "84", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getBreachList")
    public RESTfulResult getBreachList(@RequestBody(required = false) Map<String,Object> mapValue,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer apiId,
                                          String con) {

        //框计算
        if(con != null){
            if(!"undefined".equals(con)){
                //设置要查询的索引名称
                String index="get_breach_list";
                //获取查询结果
                return success(esFeign.getConResult(mapValue,index,apiId,pageNum,pageSize,con));
            }
        }
        List<Map<String, Object>> allBreachList = null;
        //如果有条件查询则跳过初始化，和创建索引
        if(mapValue.size() == 0){
            //将查询结果存入索引中
            allBreachList = amsContractBreachService.getBreachList(mapValue);
            Map<String, Object> map = new HashMap<>();
            //添加索引
            map.put("index","get_breach_list");
            //添加id
            map.put("indexId","breachListId");
            allBreachList.add(map);
            //新建索引
            esFeign.insertIndex(allBreachList);
            //删除
            allBreachList.remove(allBreachList.size()-1);
        }
        if(allBreachList == null)
            allBreachList = amsContractBreachService.getBreachList(mapValue);
        PageHelper.startPage(pageNum,pageSize);
        //分页数据
        List<Map<String, Object>> enFactoryResult = amsContractBreachService.getBreachList(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, allBreachList,enFactoryResult);
        return success(pageList);
    }


    /**
     * 新增违约规则
     * @param amsContractBreach
     * @return
     */
    @ApiModelProperty(value = "新增违约规则")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsContractBreach", value = "违约规则实体", required = false, dataType = "AmsContractBreach"),
    })
    @PostMapping("/addContractBreach")
    public RESTfulResult addContractBreach(@RequestBody AmsContractBreach amsContractBreach) {
        int result = amsContractBreachService.insert(amsContractBreach);
        return success(result);
    }

    /**
     * 逻辑删除违约规则
     * @param breachId
     * @return
     */
    @ApiModelProperty(value = "逻辑删除违约规则")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "breachId", value = "违约编号", required = false, dataType = "BigDecimal"),
    })
    @PostMapping("/deleteContractBreach/{breachId}")
    public RESTfulResult deleteContractBreach(@PathVariable("breachId") BigDecimal breachId) {
        int result = amsContractBreachService.delete(breachId);
        return success(result);
    }

    /**
     * 修改违约规则
     * @param amsContractBreach
     * @return
     */
    @ApiModelProperty(value = "修改违约规则")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsContractBreach", value = "违约规则实体", required = false, dataType = "AmsContractBreach"),
    })
    @PostMapping("/updateContractBreach")
    public RESTfulResult updateContractBreach(@RequestBody AmsContractBreach amsContractBreach) {
        int result = amsContractBreachService.updateByPrimaryKeySelective(amsContractBreach);
        return success(result);
    }

    /**
     * 得到修改渲染
     * @param breachId
     * @return
     */
    @ApiModelProperty(value = "得到修改渲染")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "breachId", value = "违约规则编号", required = false, dataType = "BigDecimal"),
    })
    @PostMapping("/selectBreachToUpdate/{breachId}")
    public RESTfulResult selectBreachToUpdate(@PathVariable("breachId") BigDecimal breachId) {
        List<Map<String,Object>> result = amsContractBreachService.selectBreachToUpdate(breachId);
        return success(result);
    }


}
