package com.steerinfo.dil.controller;

import com.steerinfo.dil.model.AmsContractTrainPrice;
import com.steerinfo.dil.service.impl.AmsContractTrainPriceServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiModelProperty;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/9/13 19:57
 * @Version:V2.0
 */
@RestController
@RequestMapping("/${api.version}/amscontracttrainprices")
public class AmsContractTrainPriceController extends BaseRESTfulController {

    @Autowired
    AmsContractTrainPriceServiceImpl amsContractTrainPriceService;
    @Autowired
    ColumnDataUtil columnDataUtil;

    /**
     * 展示火运单价
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示火运单价")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "116", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getTrainPriceList")
    public RESTfulResult getTrainPriceList(@RequestBody(required = false) Map<String,Object> mapValue,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer apiId) {
        List<Map<String, Object>> list = amsContractTrainPriceService.getTrainPriceList(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = amsContractTrainPriceService.getTrainPriceList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }


    /**
     * 新增水运单价
     * @param amsContractTrainPrice
     * @return
     */
    @ApiModelProperty(value = "新增水运单价")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsContractTrainPrice", value = "运价实体", required = false, dataType = "AmsContractTrainPrice"),
    })
    @PostMapping("/addTrainPrice")
    public RESTfulResult addTrainPrice(@RequestBody AmsContractTrainPrice amsContractTrainPrice) {
        int result = amsContractTrainPriceService.insert(amsContractTrainPrice);
        return success(result);
    }

    /**
     * 逻辑删除火运单价
     * @param priceId
     * @return
     */
    @ApiModelProperty(value = "逻辑删除火运单价")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "priceId", value = "价格编号", required = false, dataType = "BigDecimal"),
    })
    @PostMapping("/deleteTrainPrice/{priceId}")
    public RESTfulResult deleteTrainPrice(@PathVariable("priceId") BigDecimal priceId) {
        int result = amsContractTrainPriceService.delete(priceId);
        return success(result);
    }

    /**
     * 修改水运单价
     * @param amsContractTrainPrice
     * @return
     */
    @ApiModelProperty(value = "修改水运单价")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsContractTrainPrice", value = "运价实体", required = false, dataType = "AmsContractTrainPrice"),
    })
    @PostMapping("/updateTrainPrice")
    public RESTfulResult updateTrainPrice(@RequestBody AmsContractTrainPrice amsContractTrainPrice) {
        int result = amsContractTrainPriceService.updateByPrimaryKeySelective(amsContractTrainPrice);
        return success(result);
    }

    /**
     * 得到修改渲染
     * @param priceId
     * @return
     */
    @ApiModelProperty(value = "得到修改渲染")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "priceId", value = "价格编号", required = false, dataType = "BigDecimal"),
    })
    @PostMapping("/selectTrainPriceToUpdate/{priceId}")
    public RESTfulResult selectTrainPriceToUpdate(@PathVariable("priceId") BigDecimal priceId) {
        List<Map<String,Object>> result = amsContractTrainPriceService.selectTrainPriceToUpdate(priceId);
        return success(result);
    }
}
