package com.steerinfo.dil.controller;


import com.steerinfo.dil.mapper.AmstruckRailDayplanMapper;
import com.steerinfo.dil.model.AmstruckRailDayplan;
import com.steerinfo.dil.service.IAmstruckRailDayplanService;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;


/**
 * AmstruckRailDayplan RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-10-16 02:43
 * 类描述
 * 修订历史：
 * 日期：2021-10-16
 * 作者：yk
 * 参考：
 * 描述：AmstruckRailDayplan RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/amstruckraildayplans")
public class AmstruckRailDayplanController extends BaseRESTfulController {

    @Autowired
    IAmstruckRailDayplanService amstruckRailDayplanService;
    @Autowired
    ColumnDataUtil columnDataUtil;
    @Autowired
    AmstruckRailDayplanMapper amstruckRailDayplanMapper;

    @ApiOperation(value="查询所有到站信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "主键ID", required = false, dataType = "BigDecimal")
    })
    @PostMapping(value = "/getArriveName")
    public RESTfulResult getArriveName(){
        List<Map<String, Object>> arriveName = amstruckRailDayplanService.getArriveName();
        return success(arriveName);
    }

    /**
     *通过发运计划Id查询信息
     */
    @PostMapping("/getDayPlanByDayPlanId/{dayplanId}")
    public RESTfulResult getDayPlanByDayPlanId(@PathVariable("dayplanId") Integer dayplanId) {
        List<Map<String, Object>> mes = amstruckRailDayplanService.getDayPlanByDayPlanId(dayplanId);
        return success(mes);
    }

    /**
     * 查询所有的承运商
     */
    @GetMapping("/getCarrierMes")
    public RESTfulResult getCarrierMes() {
        List<Map<String, Object>> carrierMes = amstruckRailDayplanMapper.getCarrierMes();
        return success(carrierMes);
    }

    /**
     * 修改日计划
     */
    @PostMapping("/updateDayPlan")
    public RESTfulResult updateDayPlan(@RequestBody(required = false) AmstruckRailDayplan amstruckRailDayplan) {
        int i = amstruckRailDayplanMapper.updateByPrimaryKeySelective(amstruckRailDayplan);
        return success(i);
    }

    /**
     *新增日计划
     */
    @PostMapping("/addTruckRailDayPlan")
    public RESTfulResult addTruckRailDayPlan(@RequestBody AmstruckRailDayplan amstruckRailDayplan) {
        amstruckRailDayplanService.insert(amstruckRailDayplan);
        return success();
    }

    /**
     * 删除日计划
     */
    @PostMapping("/deleteTruckRailDayPlan/{dayPlanId}")
    public RESTfulResult deleteTruckRailDayPlan(@PathVariable("dayPlanId") BigDecimal dayPlanId) {
        amstruckRailDayplanService.delete(dayPlanId);
        return success("删除成功");
    }
    /**
     * 修改日计划
     */
    @PostMapping("/updateTruckRailDayPlan")
    public RESTfulResult updateTruckRailDayPlan(@RequestBody AmstruckRailDayplan amstruckRailDayplan) {
        if(amstruckRailDayplan.getCarrierId()!=null){
            amstruckRailDayplan.setDayplanReceiveStatus(new BigDecimal(1));
        }
        amstruckRailDayplanService.modify(amstruckRailDayplan);
        return success("修改成功");
    }

    /**
     * 查询日计划
     */
    @ApiModelProperty(value = "展示焦炭日计划")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "183", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getTruckRailDayPlanList")
    public RESTfulResult getTruckRailDayPlan(@RequestBody(required = false) Map<String,Object> mapValue,
                                             Integer pageNum,
                                             Integer pageSize,
                                             Integer apiId,
                                             Integer status) {
        mapValue.put("status", status);
        List<Map<String, Object>> list = amstruckRailDayplanService.getTruckRailDayPlan(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = amstruckRailDayplanService.getTruckRailDayPlan(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }
    /**
     * 查询日计划
     */
    @ApiModelProperty(value = "展示水渣日计划")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "183", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getSzTruckRailDayPlanList")
    public RESTfulResult getSzTruckRailDayPlan(@RequestBody(required = false) Map<String,Object> mapValue,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer apiId,
                                               Integer status) {
        mapValue.put("status", status);
        List<Map<String, Object>> list = amstruckRailDayplanService.getSzTruckRailDayPlan(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = amstruckRailDayplanService.getSzTruckRailDayPlan(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }

//    /**
//     * 批量下发
//     */
//    @PostMapping("/updateAllTruckRailDayPlan")
//    public RESTfulResult updateAllTruckRailDayPlan(@RequestBody(required = false) List<Map<String,Object>> mapValue) {
//        if (mapValue == null) {
//            return failed();
//        }
//        for (Map<String,Object> m:mapValue
//        ) {
//            //获取到所选择的主键
//            Integer id=Integer.parseInt(m.get("dayplanId").toString()) ;
//            //通过主键查询这条数据
//           AmstruckRailDayplan a=amstruckRailDayplanService.selectByDayPlanId(id);
//           if(a==null){
//               break;
//           }
//           a.setDayplanReceiveStatus(new BigDecimal(1));
//           //修改
//           amstruckRailDayplanService.modify(a);
//        }
//        return success();
//    }
}
