package com.steerinfo.dil.controller;

import com.alibaba.fastjson.JSON;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.model.DilNotice;
import com.steerinfo.dil.service.IDilNoticeService;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.lang.reflect.Parameter;
import java.util.*;
import java.math.BigDecimal;

/**
 * DilNotice RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-12-08 02:21
 * 类描述
 * 修订历史：
 * 日期：2021-12-08
 * 作者：generator
 * 参考：
 * 描述：DilNotice RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/dilnotices")
public class DilNoticeController extends BaseRESTfulController {

    @Autowired
    IDilNoticeService dilNoticeService;
    @Autowired
    ColumnDataUtil columnDataUtil;
    @Autowired
    ESFeign esFeign;




    /**
     * 展示公告信息
     * @param mapVal
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="获取列表", notes="分页查询")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
        @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
        @ApiImplicitParam(name = "apiId", value = "359", required = false, dataType = "BigDecimal"),
    })
    //获取整个的通知日期，标题，发布人
    @PostMapping(value = "/getNoticeList")
    public RESTfulResult getNoticeList(@RequestBody(required = false) Map<String,Object> mapVal,
                                         Integer pageNum,
                                         Integer pageSize,
                                         Integer apiId){
        List<Map<String,Object>> list = dilNoticeService.getNoticeList(mapVal);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = dilNoticeService.getNoticeList(mapVal);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }


    @ApiOperation(value="获取销售公司通知列表", notes="分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "414", required = false, dataType = "BigDecimal"),
    })
    //获取整个的通知日期，标题，发布人
    @PostMapping(value = "/getMarketingNoticeList")
    public RESTfulResult getMarketingNoticeList(@RequestBody(required = false) Map<String,Object> mapVal,
                                       Integer pageNum,
                                       Integer pageSize,
                                       Integer apiId){
        List<Map<String,Object>> list = dilNoticeService.getMarketingNoticeList(mapVal);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = dilNoticeService.getMarketingNoticeList(mapVal);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }


    @ApiOperation(value="获取承运商通知列表", notes="分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "414", required = false, dataType = "BigDecimal"),
    })
    //获取整个的通知日期，标题，发布人
    @PostMapping(value = "/getCarrierNoticeList")
    public RESTfulResult getCarrierNoticeList(@RequestBody(required = false) Map<String,Object> mapVal,
                                              Integer pageNum,
                                              Integer pageSize,
                                              Integer apiId){
        List<Map<String,Object>> list = dilNoticeService.getCarrierNoticeList(mapVal);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = dilNoticeService.getCarrierNoticeList(mapVal);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }

    @ApiOperation(value="获取收获客户通知列表", notes="分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "414", required = false, dataType = "BigDecimal"),
    })
    //获取整个的通知日期，标题，发布人
    @PostMapping(value = "/getClientNoticeList")
    public RESTfulResult getClientNoticeList(@RequestBody(required = false) Map<String,Object> mapVal,
                                                Integer pageNum,
                                                Integer pageSize,
                                                Integer apiId){
        List<Map<String,Object>> list = dilNoticeService.getClientNoticeList(mapVal);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = dilNoticeService.getClientNoticeList(mapVal);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }


    /**
     * 创建通知信息
     * @param dilNotice
     * @return
     */
    @ApiOperation(value="创建", notes="根据DilNotice对象创建")
    @ApiImplicitParam(name = "dilNotice", value = "详细实体dilNotice", required = true, dataType = "DilNotice")
    @PostMapping(value = "/insertNotice")
    public RESTfulResult insertNotice(@RequestBody DilNotice dilNotice){
        int result = dilNoticeService.insertNotice(dilNotice);
        return success(result);
    }



    /**
     * 根据id更新通知信息
     * @param dilNotice
     * @return
     */
    @ApiOperation(value="更新通知信息", notes="根据url的id来指定更新对象，并根据传过来的dilNotice信息来更新详细信息")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "Short"),
            @ApiImplicitParam(name = "dilNotice", value = "详细实体dilNotice", required = true, dataType = "DilNotice")
    })
    @PostMapping(value = "/updateNotice", produces  = "application/json;charset=UTF-8")
    public RESTfulResult updateNotice( @RequestBody DilNotice dilNotice){
        int result = dilNoticeService.updateNotice(dilNotice);
        return success(result);
    }


    /**
     * 根据id删除通知信息
     * @param id
     * @return
     */
    @ApiOperation(value="删除", notes="根据url的id来指定删除对象")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "Short")
    @PostMapping(value = "/deleteNotice/{id}")
    public RESTfulResult deleteNotice(@PathVariable("id") BigDecimal id){
        return success(dilNoticeService.deleteNotice(id));
    }



    /**
     * 根据id获取通知信息
     * @param id
     * @return
     */
    @ApiOperation(value="获取通知详细信息", notes="根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/getNoticeById/{id}")
    public RESTfulResult getNoticeById(@PathVariable("id") BigDecimal id){
        List<Map<String,Object>> list= dilNoticeService.getNoticeById(id);
        return success(list);
    }

    /**
     * 根据permissions获取最新通知信息
     * @param permissions
     * @return
     */
    @ApiOperation(value="获取通知详细信息", notes="根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "permission", value = "permission", required = true, dataType = "String")
    @PostMapping(value = "/getNewNoticeByPermission/{permissions}")
    public RESTfulResult getNewNoticeByPermission(@PathVariable("permissions")String permissions){
        BigDecimal permission=new BigDecimal(permissions);
        List<Map<String,Object>> list= dilNoticeService.getNewNoticeByPermission(permission);
        return success(list);
    }




    @ApiOperation(value = "模糊查询通知信息", notes = "分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "196", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getNoticeResultList")
    public RESTfulResult getNoticeResultList(@RequestBody(required = false) Map<String, Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               String con) {
        if (mapValue==null){
            mapValue=new HashMap<>();
        }
        //框计算
        if (con != null) {
            if (!"undefined".equals(con)) {
                //设置要查询的索引名称
                String index = "get_notice_list";
                //获取查询结果
                return success(esFeign.getConResult(mapValue, index, apiId, pageNum, pageSize, con));
            }
        }
        //初始化过滤
        List<Map<String, Object>> listTotal = null;
        //如果有条件查询则跳过初始化，和创建索引
        if (mapValue.size() == 0) {
            //将查询结果存入索引中
            listTotal = dilNoticeService.getNoticeList(null);
            Map<String, Object> map = new HashMap<>();
            //添加索引
            map.put("index", "get_notice_list");
            //添加id
            map.put("indexId", "noticeId");
            listTotal.add(map);
            //新建索引
            String s = JSON.toJSONString(listTotal);
            esFeign.insertIndex(listTotal);
            //删除
            listTotal.remove(listTotal.size() - 1);
        }
        if (listTotal == null) {
            listTotal = dilNoticeService.getNoticeList(mapValue);
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = dilNoticeService.getNoticeList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, listTotal, columnList);
        return success(data);
    }


}
