package com.steerinfo.dil.mapper;

import com.steerinfo.dil.model.AmsSaleOrder;
import com.steerinfo.framework.mapper.IBaseMapper;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Select;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

@Mapper
public interface AmsSaleOrderMapper extends IBaseMapper<AmsSaleOrder, BigDecimal> {
    //查询所有未上报销售订单信息
    List<Map<String, Object>> getSaleOrderInfo(Map<String,Object> map);
    //查询所有已上报销售订单信息
    List<Map<String, Object>> getSaleOrderReported(Map<String,Object> map);
    //根据车序号查询销售订单详细
    List<Map<String, Object>> getSaleOrderDetail(Map<String,Object> map);
    //获取销售计划名称
    List<Map<String, Object>> getSalePlanName();
    //获取发货单位
    List<Map<String, Object>> getShipperName();
    //获取收货单位
    List<Map<String, Object>> getConsigneeCompanyName();
    //查询主键最大值
    @Select("select seq_AMS_SALE_ORDER.nextval from dual")
    BigDecimal selectMaxId();
    //获取要渲染的数据
    List<Map<String, Object>> selectBySaleOrderId(BigDecimal saleOrderId);
    //删除所有从表信息
    int deleteBySaleOrderId(BigDecimal saleOrderId);
    //查询所有财务已经审批的销售订单
    List<Map<String, Object>> getAmsSaleOrderApproved(Map<String,Object> map);
    //通过销售订单号查询销售订单的修改日志
    List<Map<String, Object>> getSaleOrderUpdateLog(Map<String,Object> map);

    List<Map<String,Object>> getSaleOrderList(Map<String,Object> mapValue);
    //获取销售公司已审核的订单
    List<Map<String,Object>> getSaleOrderListBySaleCompany(Map<String,Object> map);

    //通过地址Id查询承运商ID
    List<Integer>  getCarrier(Integer param);

    //根据销售订单id查找信息
    Map<String,Object>  selectInfoBySaleOrderId(BigDecimal saleOrderId);

    //根据销售订单id查找物资信息，渲染数据
    List<Map<String,Object>> selectMaterialInfoBySaleOrderId(BigDecimal saleOrderId);

    //根据销售订单id查找车序号id和车序号与物资中间表主键
    List<Map<String,Object>> selectSaleOrderMaterialIdBySaleOrderId(BigDecimal saleOrderId);
    //根据中标区域省市县查询承运商id
    BigDecimal selectCarrierIdByprovince(Map<String,Object> map);
    //根据收货地址id查询省市县
    Map<String,Object> selectProvince(Integer addressId);
    //查询未上报的销售订单信息
    List<Map<String, Object>> getSaleOrderInfoes(Map<String,Object> map);
    //查询已上报销售订单信息
    List<Map<String, Object>> getSaleOrderReportedes(Map<String,Object> map);
    //获取销售公司已审核的订单
    List<Map<String,Object>> getSaleOrderListBySaleCompanyes(Map<String,Object> map);
    //查询财务已经审批的销售订单
    List<Map<String, Object>> getAmsSaleOrderApprovedes(Map<String,Object> map);

    // 根据销售订单主键展示销售基本信息、物资信息
    List<Map<String, Object>> getSaleOrderAndMaterialById(Map<String,Object> mapValue);

    // 销售订单物资
    List<Map<String, Object>> getSaleMaterial(Map<String,Object> loserMap);
}