package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.AmsContractTruckPriceMapper;
import com.steerinfo.dil.model.AmsContractTransportPrice;
import com.steerinfo.dil.service.IAmsContractTruckPriceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * AmsContractTransportPrice服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-09-06 07:10
 * 类描述
 * 修订历史：
 * 日期：2021-09-06
 * 作者：generator
 * 参考：
 * 描述：AmsContractTransportPrice服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "amsContractTruckPriceService")
public class AmsContractTruckPriceServiceImpl implements IAmsContractTruckPriceService {

    @Autowired
    private AmsContractTruckPriceMapper amsContractTruckPriceMapper;

    @Override
    public int addAmsContractTransportPrice(AmsContractTransportPrice amsContractTransportPrice) {
        long id;
        if(amsContractTruckPriceMapper.selectMaxId()==null){
            id = 1;
        }else {
            id = amsContractTruckPriceMapper.selectMaxId().longValue()+1;
        }
        //生成主键id
        amsContractTransportPrice.setPriceId(new BigDecimal(id));
        //获取路线Id和运价
        BigDecimal lineId = amsContractTransportPrice.getLineId();
        BigDecimal priceValue = amsContractTransportPrice.getPriceValue();
        //计算并插入吨公里
        BigDecimal priceTonKilometer = calculationPriceTonKilometer(lineId, priceValue);
        amsContractTransportPrice.setType(new BigDecimal(1));
        amsContractTransportPrice.setPriceTonKilometer(priceTonKilometer);
        amsContractTransportPrice.setInsertUsername("admin");
        amsContractTransportPrice.setInsertTime(new Date());
        amsContractTransportPrice.setUpdateUsername("admin");
        amsContractTransportPrice.setUpdateTime(new Date());
        amsContractTransportPrice.setInsertUpdateRemark("无");
        amsContractTransportPrice.setDeleted(new BigDecimal(0));
        return amsContractTruckPriceMapper.insertSelective(amsContractTransportPrice);
    }

    //计算吨公里值
    public BigDecimal calculationPriceTonKilometer(BigDecimal lineId,BigDecimal priceValue){
        //查询参考运距
        BigDecimal linePathLength = amsContractTruckPriceMapper.getLinePathLength(lineId);
        //计算吨公里	吨公里（元/吨.km） = 运价（元/吨）/ 参考运距（公里），保留4位小数
        BigDecimal priceTonKilometer = priceValue.divide(linePathLength, 4, BigDecimal.ROUND_HALF_UP);
        return priceTonKilometer;
    }

    @Override
    public List<Map<String, Object>> getAmsContractTransportPrice(Map<String, Object> map) {
        return amsContractTruckPriceMapper.getAmsContractTransportPrice(map);
    }

    @Override
    public int deleteAmsContractTransportPrice(BigDecimal priceId) {
        AmsContractTransportPrice amsContractTransportPrice = amsContractTruckPriceMapper.selectByPrimaryKey(priceId);
        amsContractTransportPrice.setDeleted(new BigDecimal(1));
        return amsContractTruckPriceMapper.updateByPrimaryKey(amsContractTransportPrice);
    }

    @Override
    public List<Map<String, Object>> getCarrierName() {
        return amsContractTruckPriceMapper.getCarrierName();
    }

    @Override
    public List<Map<String, Object>> getLineNo() {
        return amsContractTruckPriceMapper.getLineNo();
    }

    @Override
    public List<Map<String, Object>> getCapacityNumber() {
        return amsContractTruckPriceMapper.getCapacityNumber();
    }

    @Override
    public List<Map<String, Object>> getAddressDeliveryAddress(Map<String,Object> map) {
        return amsContractTruckPriceMapper.getAddressDeliveryAddress(map);
    }

    @Override
    public List<Map<String, Object>> selectByPriceId(BigDecimal priceId) {
        return amsContractTruckPriceMapper.selectByPriceId(priceId);
    }

    @Override
    public int updateAmsContractTransportPrice(AmsContractTransportPrice amsContractTransportPrice) {
        BigDecimal priceId = amsContractTransportPrice.getPriceId();
        //获取未修改前的汽运单价信息
        AmsContractTransportPrice amsContractTransportPrice1 = amsContractTruckPriceMapper.selectByPrimaryKey(priceId);
        //获取路线Id和运价
        BigDecimal lineId = amsContractTransportPrice.getLineId();
        BigDecimal priceValue = amsContractTransportPrice.getPriceValue();
        //若运价修改了
        if(amsContractTransportPrice.getPriceValue()!=amsContractTransportPrice1.getPriceValue()){
            //计算并插入吨公里
            BigDecimal priceTonKilometer = calculationPriceTonKilometer(lineId, priceValue);
            amsContractTransportPrice.setPriceTonKilometer(priceTonKilometer);
        }
        amsContractTransportPrice.setUpdateTime(new Date());
        return amsContractTruckPriceMapper.updateByPrimaryKeySelective(amsContractTransportPrice);
    }

    @Override
    public List<Map<String, Object>> getOriginAndNowOilPrice() {
        return amsContractTruckPriceMapper.getOriginAndNowOilPrice();
    }

    /**
     * 批量修改油价
     * @return
     */
    @Override
    public int batchUpdateTransportPriceByOilPrice() {
        //获取所有油价信息
        List<Map<String, Object>> originAndNowOilPrice = amsContractTruckPriceMapper.getOriginAndNowOilPrice();
        //原油价
        BigDecimal originOilPrice = new BigDecimal("1");
        //现油价
        BigDecimal nowOilPrice = new BigDecimal("0");
        for (int i = 0; i < 2; i++) {
            if(i==0){
                nowOilPrice = (BigDecimal) originAndNowOilPrice.get(i).get("priceValue");
            }else if(i==1){
                originOilPrice = (BigDecimal) originAndNowOilPrice.get(i).get("priceValue");
            }
        }
        //油价变动率
        Double updateOilPrice = nowOilPrice.doubleValue()/originOilPrice.doubleValue()-1;
        //获取原运价和吨公里数
        List<Map<String, Object>> priceValueAndPriceTonKilometer = amsContractTruckPriceMapper.getPriceValueAndPriceTonKilometer();

        if(updateOilPrice>0.05||updateOilPrice<-0.05) {
            //逐条修改吨公里数
            for (Map<String, Object> stringObjectMap : priceValueAndPriceTonKilometer) {
                //主键Id
                BigDecimal priceId = (BigDecimal) stringObjectMap.get("priceId");
                //原运价
                BigDecimal priceValue = (BigDecimal) stringObjectMap.get("priceValue");
                //吨公里数
                BigDecimal priceTonKilometer = (BigDecimal) stringObjectMap.get("priceTonKilometer");
                //参考距离,四舍五入，保留两位小数
                BigDecimal distance;
                if (priceTonKilometer.doubleValue() != 0) {
                    distance = priceValue.divide(priceTonKilometer, 2, BigDecimal.ROUND_HALF_UP);
                    //现运价
                    Double nowPriceValue = priceValue.doubleValue() * 0.65 + priceValue.doubleValue() * 0.35 * (1 + updateOilPrice);
                    BigDecimal nowPriceValue1 = new BigDecimal(nowPriceValue);
                    //新吨公里数
                    BigDecimal newPriceTonKilometer = nowPriceValue1.divide(distance, 4, BigDecimal.ROUND_HALF_UP);
                    //通过主键修改一条吨公里数
                    amsContractTruckPriceMapper.updatePriceTonKilometer(priceId, newPriceTonKilometer);
                }
                return amsContractTruckPriceMapper.batchUpdateTransportPriceByOilPrice(updateOilPrice);
            }
        }
        return 0;
    }

}
